# Questioned
![Python package](https://github.com/DavidVisscher/questioned/workflows/Python%20package/badge.svg)

Exam generator for testing computer architectures at the Hanze University of Applied Sciences.

Can generate exams based on the `exam_spec.yml` file. Which contains information about the layout and content of the design.

The software is written in such a way that it can be given to students, so they can generate their own practice exam, but can also be used to generate the final exam.

All secrets are kept within the `exam_spec.yml` file.
